# PT Utility Package

- Time Decorator
  - decorator to calculate execution time.
  - `from pt_library import calculate_time`
- Notification
  - Currently, supports only Telegram Notifications.
  - `from pt_library.notifications import telegram_notification`
- DB Connection
  - Run Query on SQL and return records.
  - `from pt_library.sql import run_query`